import Image from "next/image";
import img from "../../../../public/imgaes/clear-icon.svg";
import classNames from "classnames";

type InputProps = {
  label?: string;
  error?: boolean;
  onClear?: () => void;
  onEnter?: (value: string) => void;
} & React.InputHTMLAttributes<HTMLInputElement>;

export default function Input({
  label,
  onClear,
  value,
  error,
  onEnter,
  ...props
}: InputProps) {
  const handleKeyDown = (e: React.KeyboardEvent<HTMLInputElement>) => {
    if (e.key === "Enter") {
      onEnter?.(value as string);
    }
  };

  const inputWrapper = classNames(
    "flex items-center rounded-[10px] border-[rgba(255,255,255,0.451)] border-[0.2px]",
    { "shadow-[0_0_3px_3px_rgb(223,56,56)]": error === true }
  );

  const inputClass = classNames(
    "outline-none h-[12px] w-full text-[15px] text-[var(--primary-text-color)] bg-[var(--secondary-bg-color)] py-[1.5rem] font-[Inter-Medium]",
    {
      "!px-[1rem] !py-[1.5rem] rounded-tl-[10px] rounded-bl-[10px]":
        value != "",
      "!rounded-tr-[10px] rounded-br-[10px]": value == "",
    }
  );

  const searchWrapper = classNames(
    "py-[1rem] px-[1rem] bg-[var(--secondary-bg-color)] rounded-tl-[10px] rounded-bl-[10px]",
    {
      hidden: value != "",
    }
  );

  const clearWrapper = classNames(
    "rounded-tr-[10px] rounded-br-[10px] bg-[var(--secondary-bg-color)] p-[1rem] cursor-pointer",
    {
      hidden: value === "",
    }
  );

  return (
    <>
      {label && (
        <div className={"font-[Inter-Medium] py-[0.5rem]"}>{label}</div>
      )}
      <div className={inputWrapper}>
        <div className={searchWrapper}>
          <svg
            width="20px"
            height="15px"
            viewBox="0 0 24 24"
            fill="none"
            xmlns="http://www.w3.org/2000/svg"
          >
            <g id="SVGRepo_bgCarrier" strokeWidth="0"></g>
            <g
              id="SVGRepo_tracerCarrier"
              strokeLinecap="round"
              strokeLinejoin="round"
              stroke="#CCCCCC"
              strokeWidth="0.384"
            ></g>
            <g id="SVGRepo_iconCarrier">
              <path
                d="M15.7955 15.8111L21 21M18 10.5C18 14.6421 14.6421 18 10.5 18C6.35786 18 3 14.6421 3 10.5C3 6.35786 6.35786 3 10.5 3C14.6421 3 18 6.35786 18 10.5Z"
                stroke="#787373"
                strokeWidth="2"
                strokeLinecap="round"
                strokeLinejoin="round"
              ></path>{" "}
            </g>
          </svg>
        </div>
        <input
          className={inputClass}
          value={value}
          onKeyDown={handleKeyDown}
          name="input"
          {...props}
        />
        <div className={clearWrapper} onClick={onClear}>
          <Image height={20} src={img} alt="img" />
        </div>
      </div>
    </>
  );
}
